@@ -1,17 +1,18 @@
 package apk
 
 import (
+	"github.com/anchore/grype/grype/search"
 	"testing"
 
 	"github.com/anchore/grype/grype/db"
 	grypeDB "github.com/anchore/grype/grype/db/v3"
 	"github.com/anchore/grype/grype/distro"
 	"github.com/anchore/grype/grype/match"
-	"github.com/anchore/grype/grype/matcher/common"
 	"github.com/anchore/grype/grype/pkg"
 	"github.com/anchore/grype/grype/vulnerability"
 	syftPkg "github.com/anchore/syft/syft/pkg"
 	"github.com/go-test/deep"
+	"github.com/google/uuid"
 	"github.com/stretchr/testify/assert"
 )
 
@@ -60,6 +61,7 @@ func TestSecDBOnlyMatch(t *testing.T) {
 	}
 
 	p := pkg.Package{
+		ID:      pkg.ID(uuid.NewString()),
 		Name:    "libvncserver",
 		Version: "0.9.9",
 		Type:    syftPkg.ApkPkg,
@@ -73,11 +75,12 @@ func TestSecDBOnlyMatch(t *testing.T) {
 
 	expected := []match.Match{
 		{
-			Type:          match.ExactDirectMatch,
+
 			Vulnerability: *vulnFound,
 			Package:       p,
-			MatchDetails: []match.Details{
+			Details: []match.Detail{
 				{
+					Type:       match.ExactDirectMatch,
 					Confidence: 1.0,
 					SearchedBy: map[string]interface{}{
 						"distro": map[string]string{
@@ -145,6 +148,7 @@ func TestBothSecdbAndNvdMatches(t *testing.T) {
 	}
 
 	p := pkg.Package{
+		ID:      pkg.ID(uuid.NewString()),
 		Name:    "libvncserver",
 		Version: "0.9.9",
 		Type:    syftPkg.ApkPkg,
@@ -159,11 +163,12 @@ func TestBothSecdbAndNvdMatches(t *testing.T) {
 
 	expected := []match.Match{
 		{
-			Type:          match.ExactDirectMatch,
+
 			Vulnerability: *vulnFound,
 			Package:       p,
-			MatchDetails: []match.Details{
+			Details: []match.Detail{
 				{
+					Type:       match.ExactDirectMatch,
 					Confidence: 1.0,
 					SearchedBy: map[string]interface{}{
 						"distro": map[string]string{
@@ -230,6 +235,7 @@ func TestBothSecdbAndNvdMatches_DifferentPackageName(t *testing.T) {
 		t.Fatalf("failed to create a new distro: %+v", err)
 	}
 	p := pkg.Package{
+		ID:      pkg.ID(uuid.NewString()),
 		Name:    "libvncserver",
 		Version: "0.9.9",
 		Type:    syftPkg.ApkPkg,
@@ -245,11 +251,12 @@ func TestBothSecdbAndNvdMatches_DifferentPackageName(t *testing.T) {
 
 	expected := []match.Match{
 		{
-			Type:          match.ExactDirectMatch,
+
 			Vulnerability: *vulnFound,
 			Package:       p,
-			MatchDetails: []match.Details{
+			Details: []match.Detail{
 				{
+					Type:       match.ExactDirectMatch,
 					Confidence: 1.0,
 					SearchedBy: map[string]interface{}{
 						"distro": map[string]string{
@@ -303,6 +310,7 @@ func TestNvdOnlyMatches(t *testing.T) {
 		t.Fatalf("failed to create a new distro: %+v", err)
 	}
 	p := pkg.Package{
+		ID:      pkg.ID(uuid.NewString()),
 		Name:    "libvncserver",
 		Version: "0.9.9",
 		Type:    syftPkg.ApkPkg,
@@ -317,17 +325,18 @@ func TestNvdOnlyMatches(t *testing.T) {
 
 	expected := []match.Match{
 		{
-			Type:          match.FuzzyMatch,
+
 			Vulnerability: *vulnFound,
 			Package:       p,
-			MatchDetails: []match.Details{
+			Details: []match.Detail{
 				{
+					Type:       match.CPEMatch,
 					Confidence: 0.9,
-					SearchedBy: common.SearchedByCPEs{
+					SearchedBy: search.CPEParameters{
 						CPEs:      []string{"cpe:2.3:a:*:libvncserver:0.9.9:*:*:*:*:*:*:*"},
 						Namespace: "nvd",
 					},
-					Found: common.FoundCPEs{
+					Found: search.CPEResult{
 						CPEs:              []string{vulnFound.CPEs[0].BindToFmtString()},
 						VersionConstraint: vulnFound.Constraint.String(),
 					},
@@ -380,6 +389,7 @@ func TestNvdMatchesWithSecDBFix(t *testing.T) {
 		t.Fatalf("failed to create a new distro: %+v", err)
 	}
 	p := pkg.Package{
+		ID:      pkg.ID(uuid.NewString()),
 		Name:    "libvncserver",
 		Version: "0.9.11",
 		Type:    syftPkg.ApkPkg,
@@ -433,6 +443,7 @@ func TestNvdMatchesNoConstraintWithSecDBFix(t *testing.T) {
 		t.Fatalf("failed to create a new distro: %+v", err)
 	}
 	p := pkg.Package{
+		ID:      pkg.ID(uuid.NewString()),
 		Name:    "libvncserver",
 		Version: "0.9.11",
 		Type:    syftPkg.ApkPkg,
@@ -476,10 +487,15 @@ func TestDistroMatchBySourceIndirection(t *testing.T) {
 		t.Fatalf("failed to create a new distro: %+v", err)
 	}
 	p := pkg.Package{
-		Name:     "musl-utils",
-		Version:  "1.3.2-r0",
-		Type:     syftPkg.ApkPkg,
-		Metadata: pkg.ApkMetadata{OriginPackage: "musl"},
+		ID:      pkg.ID(uuid.NewString()),
+		Name:    "musl-utils",
+		Version: "1.3.2-r0",
+		Type:    syftPkg.ApkPkg,
+		Upstreams: []pkg.UpstreamPackage{
+			{
+				Name: "musl",
+			},
+		},
 	}
 
 	vulnFound, err := vulnerability.NewVulnerability(secDbVuln)
@@ -487,11 +503,12 @@ func TestDistroMatchBySourceIndirection(t *testing.T) {
 
 	expected := []match.Match{
 		{
-			Type:          match.ExactIndirectMatch,
+
 			Vulnerability: *vulnFound,
 			Package:       p,
-			MatchDetails: []match.Details{
+			Details: []match.Detail{
 				{
+					Type:       match.ExactIndirectMatch,
 					Confidence: 1.0,
 					SearchedBy: map[string]interface{}{
 						"distro": map[string]string{
@@ -546,6 +563,7 @@ func TestNVDMatchBySourceIndirection(t *testing.T) {
 		t.Fatalf("failed to create a new distro: %+v", err)
 	}
 	p := pkg.Package{
+		ID:      pkg.ID(uuid.NewString()),
 		Name:    "musl-utils",
 		Version: "1.3.2-r0",
 		Type:    syftPkg.ApkPkg,
@@ -553,7 +571,11 @@ func TestNVDMatchBySourceIndirection(t *testing.T) {
 			must(syftPkg.NewCPE("cpe:2.3:a:musl-utils:musl-utils:*:*:*:*:*:*:*:*")),
 			must(syftPkg.NewCPE("cpe:2.3:a:musl-utils:musl-utils:*:*:*:*:*:*:*:*")),
 		},
-		Metadata: pkg.ApkMetadata{OriginPackage: "musl"},
+		Upstreams: []pkg.UpstreamPackage{
+			{
+				Name: "musl",
+			},
+		},
 	}
 
 	vulnFound, err := vulnerability.NewVulnerability(nvdVuln)
@@ -562,17 +584,17 @@ func TestNVDMatchBySourceIndirection(t *testing.T) {
 
 	expected := []match.Match{
 		{
-			Type:          match.FuzzyMatch,
 			Vulnerability: *vulnFound,
 			Package:       p,
-			MatchDetails: []match.Details{
+			Details: []match.Detail{
 				{
+					Type:       match.CPEMatch,
 					Confidence: 0.9,
-					SearchedBy: common.SearchedByCPEs{
+					SearchedBy: search.CPEParameters{
 						CPEs:      []string{"cpe:2.3:a:musl:musl:*:*:*:*:*:*:*:*"},
 						Namespace: "nvd",
 					},
-					Found: common.FoundCPEs{
+					Found: search.CPEResult{
 						CPEs:              []string{vulnFound.CPEs[0].BindToFmtString()},
 						VersionConstraint: vulnFound.Constraint.String(),
 					},
