@@ -3,6 +3,9 @@ package dpkg
 import (
 	"testing"
 
+	"github.com/google/uuid"
+	"github.com/stretchr/testify/require"
+
 	"github.com/stretchr/testify/assert"
 
 	"github.com/anchore/grype/grype/distro"
@@ -15,11 +18,14 @@ import (
 func TestMatcherDpkg_matchBySourceIndirection(t *testing.T) {
 	matcher := Matcher{}
 	p := pkg.Package{
+		ID:      pkg.ID(uuid.NewString()),
 		Name:    "neutron",
 		Version: "2014.1.3-6",
 		Type:    syftPkg.DebPkg,
-		Metadata: pkg.DpkgMetadata{
-			Source: "neutron-devel",
+		Upstreams: []pkg.UpstreamPackage{
+			{
+				Name: "neutron-devel",
+			},
 		},
 	}
 
@@ -29,7 +35,7 @@ func TestMatcherDpkg_matchBySourceIndirection(t *testing.T) {
 	}
 
 	store := newMockProvider()
-	actual, err := matcher.matchBySourceIndirection(store, d, p)
+	actual, err := matcher.matchUpstreamPackages(store, d, p)
 
 	assert.Len(t, actual, 2, "unexpected indirect matches count")
 
@@ -37,9 +43,12 @@ func TestMatcherDpkg_matchBySourceIndirection(t *testing.T) {
 	for _, a := range actual {
 		foundCVEs.Add(a.Vulnerability.ID)
 
-		assert.Equal(t, match.ExactIndirectMatch, a.Type, "indirect match not indicated")
+		require.NotEmpty(t, a.Details)
+		for _, d := range a.Details {
+			assert.Equal(t, match.ExactIndirectMatch, d.Type, "indirect match not indicated")
+		}
 		assert.Equal(t, p.Name, a.Package.Name, "failed to capture original package name")
-		for _, detail := range a.MatchDetails {
+		for _, detail := range a.Details {
 			assert.Equal(t, matcher.Type(), detail.Matcher, "failed to capture matcher type")
 		}
 	}
