@@ -5,9 +5,8 @@ import (
 	"flag"
 	"testing"
 
-	"github.com/anchore/syft/syft/linux"
-
 	"github.com/anchore/stereoscope/pkg/file"
+	"github.com/anchore/syft/syft/linux"
 
 	"github.com/anchore/go-testutils"
 	"github.com/anchore/grype/grype/match"
@@ -37,10 +36,13 @@ func TestJsonImgsPresenter(t *testing.T) {
 		return syftSource.NewLocationFromImage("", *ref, img)
 	}
 
+	epoch := 2
+
 	var pkg1 = pkg.Package{
+		ID:      pkg.ID("package-1-id"),
 		Name:    "package-1",
 		Version: "1.1.1",
-		Type:    syftPkg.DebPkg,
+		Type:    syftPkg.RpmPkg,
 		Locations: []syftSource.Location{
 			getImageLocation("/somefile-1.txt"),
 		},
@@ -53,10 +55,18 @@ func TestJsonImgsPresenter(t *testing.T) {
 				Language: "python",
 			},
 		},
-		Metadata: pkg.DpkgMetadata{Source: "a source!"},
+		Upstreams: []pkg.UpstreamPackage{
+			{
+				Name:    "nothing",
+				Version: "3.2",
+			},
+		},
+		MetadataType: pkg.RpmdbMetadataType,
+		Metadata:     pkg.RpmdbMetadata{Epoch: &epoch},
 	}
 
 	var pkg2 = pkg.Package{
+		ID:      pkg.ID("package-2-id"),
 		Name:    "package-2",
 		Version: "2.2.2",
 		Type:    syftPkg.DebPkg,
@@ -66,7 +76,7 @@ func TestJsonImgsPresenter(t *testing.T) {
 	}
 
 	var match1 = match.Match{
-		Type: match.ExactDirectMatch,
+
 		Vulnerability: vulnerability.Vulnerability{
 			ID:        "CVE-1999-0001",
 			Namespace: "source-1",
@@ -77,8 +87,9 @@ func TestJsonImgsPresenter(t *testing.T) {
 			},
 		},
 		Package: pkg1,
-		MatchDetails: []match.Details{
+		Details: []match.Detail{
 			{
+				Type:    match.ExactDirectMatch,
 				Matcher: match.DpkgMatcher,
 				SearchedBy: map[string]interface{}{
 					"distro": map[string]string{
@@ -94,14 +105,15 @@ func TestJsonImgsPresenter(t *testing.T) {
 	}
 
 	var match2 = match.Match{
-		Type: match.ExactIndirectMatch,
+
 		Vulnerability: vulnerability.Vulnerability{
 			ID:        "CVE-1999-0002",
 			Namespace: "source-2",
 		},
 		Package: pkg1,
-		MatchDetails: []match.Details{
+		Details: []match.Detail{
 			{
+				Type:    match.ExactIndirectMatch,
 				Matcher: match.DpkgMatcher,
 				SearchedBy: map[string]interface{}{
 					"cpe": "somecpe",
@@ -114,7 +126,7 @@ func TestJsonImgsPresenter(t *testing.T) {
 	}
 
 	var match3 = match.Match{
-		Type: match.ExactIndirectMatch,
+
 		Vulnerability: vulnerability.Vulnerability{
 			ID:        "CVE-1999-0003",
 			Namespace: "source-1",
@@ -125,8 +137,9 @@ func TestJsonImgsPresenter(t *testing.T) {
 			},
 		},
 		Package: pkg1,
-		MatchDetails: []match.Details{
+		Details: []match.Detail{
 			{
+				Type:    match.ExactIndirectMatch,
 				Matcher: match.DpkgMatcher,
 				SearchedBy: map[string]interface{}{
 					"language": "java",
@@ -139,7 +152,7 @@ func TestJsonImgsPresenter(t *testing.T) {
 	}
 
 	matches := match.NewMatches()
-	matches.Add(pkg1, match1, match2, match3)
+	matches.Add(match1, match2, match3)
 
 	packages := []pkg.Package{pkg1, pkg2}
 
@@ -195,10 +208,6 @@ func TestJsonDirsPresenter(t *testing.T) {
 		Locations: []syftSource.Location{
 			syftSource.NewLocation("/some/path/pkg1"),
 		},
-		MetadataType: syftPkg.DpkgMetadataType,
-		Metadata: syftPkg.DpkgMetadata{
-			Source: "a source!",
-		},
 	})
 
 	var pkg1 pkg.Package
@@ -211,7 +220,7 @@ func TestJsonDirsPresenter(t *testing.T) {
 	}
 
 	var match1 = match.Match{
-		Type: match.ExactDirectMatch,
+
 		Vulnerability: vulnerability.Vulnerability{
 			ID:        "CVE-1999-0001",
 			Namespace: "source-1",
@@ -222,8 +231,9 @@ func TestJsonDirsPresenter(t *testing.T) {
 			},
 		},
 		Package: pkg1,
-		MatchDetails: []match.Details{
+		Details: []match.Detail{
 			{
+				Type:    match.ExactDirectMatch,
 				Matcher: match.DpkgMatcher,
 				SearchedBy: map[string]interface{}{
 					"distro": map[string]string{
@@ -239,14 +249,15 @@ func TestJsonDirsPresenter(t *testing.T) {
 	}
 
 	var match2 = match.Match{
-		Type: match.ExactIndirectMatch,
+
 		Vulnerability: vulnerability.Vulnerability{
 			ID:        "CVE-1999-0002",
 			Namespace: "source-2",
 		},
 		Package: pkg1,
-		MatchDetails: []match.Details{
+		Details: []match.Detail{
 			{
+				Type:    match.ExactIndirectMatch,
 				Matcher: match.DpkgMatcher,
 				SearchedBy: map[string]interface{}{
 					"cpe": "somecpe",
@@ -259,7 +270,7 @@ func TestJsonDirsPresenter(t *testing.T) {
 	}
 
 	var match3 = match.Match{
-		Type: match.ExactIndirectMatch,
+
 		Vulnerability: vulnerability.Vulnerability{
 			ID:        "CVE-1999-0003",
 			Namespace: "source-1",
@@ -270,8 +281,9 @@ func TestJsonDirsPresenter(t *testing.T) {
 			},
 		},
 		Package: pkg1,
-		MatchDetails: []match.Details{
+		Details: []match.Detail{
 			{
+				Type:    match.ExactIndirectMatch,
 				Matcher: match.DpkgMatcher,
 				SearchedBy: map[string]interface{}{
 					"language": "java",
@@ -284,7 +296,7 @@ func TestJsonDirsPresenter(t *testing.T) {
 	}
 
 	matches := match.NewMatches()
-	matches.Add(pkg1, match1, match2, match3)
+	matches.Add(match1, match2, match3)
 
 	s, err := syftSource.NewFromDirectory("/some/path")
 	if err != nil {
