@@ -15,43 +15,57 @@ import (
 func TestPackagesAreSorted(t *testing.T) {
 
 	var pkg1 = pkg.Package{
+		ID:      "package-1-id",
 		Name:    "package-1",
 		Version: "1.1.1",
 		Type:    syftPkg.DebPkg,
 	}
 
 	var pkg2 = pkg.Package{
+		ID:      "package-2-id",
 		Name:    "package-2",
 		Version: "2.2.2",
 		Type:    syftPkg.DebPkg,
 	}
 
 	var match1 = match.Match{
-		Type: match.ExactDirectMatch,
 		Vulnerability: vulnerability.Vulnerability{
 			ID: "CVE-1999-0003",
 		},
 		Package: pkg1,
+		Details: match.Details{
+			{
+				Type: match.ExactDirectMatch,
+			},
+		},
 	}
 
 	var match2 = match.Match{
-		Type: match.ExactIndirectMatch,
 		Vulnerability: vulnerability.Vulnerability{
 			ID: "CVE-1999-0002",
 		},
 		Package: pkg1,
+		Details: match.Details{
+			{
+				Type: match.ExactIndirectMatch,
+			},
+		},
 	}
 
 	var match3 = match.Match{
-		Type: match.ExactIndirectMatch,
 		Vulnerability: vulnerability.Vulnerability{
 			ID: "CVE-1999-0001",
 		},
 		Package: pkg1,
+		Details: match.Details{
+			{
+				Type: match.ExactIndirectMatch,
+			},
+		},
 	}
 
 	matches := match.NewMatches()
-	matches.Add(pkg1, match1, match2, match3)
+	matches.Add(match1, match2, match3)
 
 	packages := []pkg.Package{pkg1, pkg2}
 
