@@ -2,14 +2,13 @@ package integration
 
 import (
 	"fmt"
+	"github.com/anchore/grype/grype/search"
 	"testing"
 
 	"github.com/stretchr/testify/require"
 
 	"github.com/anchore/grype/grype/db"
 
-	"github.com/anchore/grype/grype/matcher/common"
-
 	"github.com/anchore/grype/grype"
 	"github.com/anchore/grype/grype/match"
 	"github.com/anchore/syft/syft/source"
@@ -23,14 +22,15 @@ func TestMatchBySBOMDocument(t *testing.T) {
 		name            string
 		fixture         string
 		expectedIDs     []string
-		expectedDetails []match.Details
+		expectedDetails []match.Detail
 	}{
 		{
 			name:        "single KB package",
 			fixture:     "test-fixtures/sbom/syft-sbom-with-kb-packages.json",
 			expectedIDs: []string{"CVE-2016-3333"},
-			expectedDetails: []match.Details{
+			expectedDetails: []match.Detail{
 				{
+					Type: match.ExactDirectMatch,
 					SearchedBy: map[string]interface{}{
 						"distro": map[string]string{
 							"type":    "windows",
@@ -54,15 +54,16 @@ func TestMatchBySBOMDocument(t *testing.T) {
 			name:        "unknown package type",
 			fixture:     "test-fixtures/sbom/syft-sbom-with-unknown-packages.json",
 			expectedIDs: []string{"CVE-bogus-my-package-1", "CVE-bogus-my-package-2-python"},
-			expectedDetails: []match.Details{
+			expectedDetails: []match.Detail{
 				{
-					SearchedBy: common.SearchedByCPEs{
+					Type: match.CPEMatch,
+					SearchedBy: search.CPEParameters{
 						Namespace: "nvd",
 						CPEs: []string{
 							"cpe:2.3:a:bogus:my-package:1.0.5:*:*:*:*:*:*:*",
 						},
 					},
-					Found: common.FoundCPEs{
+					Found: search.CPEResult{
 						VersionConstraint: "< 2.0 (unknown)",
 						CPEs: []string{
 							"cpe:2.3:a:bogus:my-package:*:*:*:*:*:*:something:*",
@@ -72,6 +73,7 @@ func TestMatchBySBOMDocument(t *testing.T) {
 					Confidence: 0.9,
 				},
 				{
+					Type: match.ExactDirectMatch,
 					SearchedBy: map[string]interface{}{
 						"language":  "python",
 						"namespace": "github:python",
@@ -91,10 +93,10 @@ func TestMatchBySBOMDocument(t *testing.T) {
 			provider := db.NewVulnerabilityProvider(newMockDbStore())
 			matches, _, _, err := grype.FindVulnerabilities(provider, fmt.Sprintf("sbom:%s", test.fixture), source.SquashedScope, nil)
 			assert.NoError(t, err)
-			details := make([]match.Details, 0)
+			details := make([]match.Detail, 0)
 			ids := strset.New()
 			for _, m := range matches.Sorted() {
-				details = append(details, m.MatchDetails...)
+				details = append(details, m.Details...)
 				ids.Add(m.Vulnerability.ID)
 			}
 
